@@ -122,7 +122,7 @@ polari_room_should_highlight_message (PolariRoom *room,
 {
   PolariRoomPrivate *priv;
   TpConnection *conn;
-  TpContact *sender, *self;
+  TpContact *self;
   char *text;
   gboolean result;
 
@@ -310,7 +310,7 @@ on_group_contacts_changed (TpChannel  *channel,
   TpChannelGroupChangeReason reason;
   const char *raw_message;
   char *message = NULL;
-  int i;
+  guint i;
 
   reason = tp_asv_get_uint32 (details, "change-reason", NULL);
   raw_message = tp_asv_get_string (details, "message");
@@ -348,6 +348,15 @@ on_group_contacts_changed (TpChannel  *channel,
         g_signal_emit (user_data, signals[MEMBER_JOINED], 0,
                        g_ptr_array_index (added, i));
       break;
+    case TP_CHANNEL_GROUP_CHANGE_REASON_BUSY:
+    case TP_CHANNEL_GROUP_CHANGE_REASON_ERROR:
+    case TP_CHANNEL_GROUP_CHANGE_REASON_INVALID_CONTACT:
+    case TP_CHANNEL_GROUP_CHANGE_REASON_INVITED:
+    case TP_CHANNEL_GROUP_CHANGE_REASON_NO_ANSWER:
+    case TP_CHANNEL_GROUP_CHANGE_REASON_PERMISSION_DENIED:
+    case TP_CHANNEL_GROUP_CHANGE_REASON_SEPARATED:
+    default:
+      break; /* no special handling */
     }
 
   g_signal_emit (user_data, signals[MEMBERS_CHANGED], 0);
@@ -454,7 +463,7 @@ polari_room_set_account (PolariRoom *room,
 
 static void
 polari_room_set_type (PolariRoom *room,
-                      int         type)
+                      guint       type)
 {
   PolariRoomPrivate *priv;
 
@@ -603,7 +612,7 @@ polari_room_get_property (GObject    *object,
       g_value_set_object (value, priv->account);
       break;
     case PROP_TYPE:
-      g_value_set_int (value, priv->type);
+      g_value_set_uint (value, priv->type);
       break;
     case PROP_CHANNEL_NAME:
       g_value_set_string (value, priv->channel_name);
@@ -628,9 +637,12 @@ polari_room_set_property (GObject      *object,
                           const GValue *value,
                           GParamSpec   *pspec)
 {
+  PolariRoom *room;
+
   g_return_if_fail (POLARI_IS_ROOM (object));
   g_return_if_fail (G_IS_OBJECT (object));
-  PolariRoom *room = POLARI_ROOM(object);
+
+  room = POLARI_ROOM(object);
 
   switch (prop_id)
     {
@@ -638,7 +650,7 @@ polari_room_set_property (GObject      *object,
       polari_room_set_account (room, g_value_get_object (value));
       break;
     case PROP_TYPE:
-      polari_room_set_type (room, g_value_get_int (value));
+      polari_room_set_type (room, g_value_get_uint (value));
       break;
     case PROP_CHANNEL_NAME:
       polari_room_set_channel_name (room, g_value_get_string (value));
@@ -718,7 +730,7 @@ polari_room_class_init (PolariRoomClass *klass)
                          G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
 
   props[PROP_TYPE] =
-    g_param_spec_int ("type",
+    g_param_spec_uint ("type",
                        "Type",
                        "Type",
                        TP_HANDLE_TYPE_NONE,
